jactorch.nn.quickaccess
=======================

.. automodule:: jactorch.nn.quickaccess

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      get_activation
      get_batcnnorm
      get_dropout
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: get_activation

.. autofunction:: get_batcnnorm

.. autofunction:: get_dropout


